import os
from setuptools import setup
from elisa.core.utils.dist import find_packages, TrialTest, Clean

packages, package_dir = find_packages(os.path.dirname(__file__))
cmdclass = dict(test=TrialTest, clean=Clean)

setup(name='elisa-plugin-winremote',
    version='0.1',
    description='Win32 remote control support plugin for Streamzap remotes',
    license='GPL3',
    author='Elisa Developers',
    author_email='elisa@lists.fluendo.com',
    namespace_packages=['elisa', 'elisa.plugins'],
    packages=packages,
    package_dir=package_dir,
    cmdclass=cmdclass,
    entry_points="""
    [elisa.core.components.input_provider]
    StreamzapInput = elisa.plugins.winremote.streamzap_input:StreamzapInput
    """)
